@@ -2,18 +2,13 @@ package SyForm::Exception::UnknownErrorOnCreate;
 BEGIN {
   $SyForm::Exception::UnknownErrorOnCreate::AUTHORITY = 'cpan:GETTY';
 }
-$SyForm::Exception::UnknownErrorOnCreate::VERSION = '0.003';
+$SyForm::Exception::UnknownErrorOnCreate::VERSION = '0.004';
 use Moose;
 extends 'SyForm::Exception';
 
 with qw(
   SyForm::Exception::Role::WithOriginalError
-);
-
-has create_args => (
-  is => 'ro',
-  isa => 'ArrayRef',
-  required => 1,
+  SyForm::Exception::Role::WithCreateArgs
 );
 
 sub throw_with_args {
@@ -37,7 +32,7 @@ SyForm::Exception::UnknownErrorOnCreate
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 AUTHOR
 
