@@ -3,7 +3,7 @@ BEGIN {
   $SyForm::Field::Process::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Role for processed fields
-$SyForm::Field::Process::VERSION = '0.003';
+$SyForm::Field::Process::VERSION = '0.004';
 use Moose::Role;
 use namespace::autoclean;
 
@@ -12,11 +12,15 @@ sub has_value_by_args {
   return exists($args{$self->name}) ? 1 : 0;
 }
 
-sub get_value_by_args {
+sub value_values_roles_by_args {
   my ( $self, %args ) = @_;
-  SyForm->throw( UnexpectedCallToGetValueByArgs => $self )
-    unless $self->has_value_by_args(%args);
-  return $self->get_value_by_arg($args{$self->name});
+  return $self->get_value_by_arg($args{$self->name}),
+    $self->values_roles_by_args(%args);
+}
+
+sub values_roles_by_args { 
+  my ( $self, %args ) = @_;
+  return;
 }
 
 sub get_value_by_arg {
@@ -26,13 +30,24 @@ sub get_value_by_arg {
 
 sub has_result_by_values {
   my ( $self, $values ) = @_;
-  my $has = 'has_'.($self->name);
+  my $has = $self->has_name;
   return $values->$has ? 1 : 0;
 }
 
+sub result_results_roles_by_values {
+  my ( $self, $values ) = @_;
+  my $name = $self->name;
+  return $self->get_result_by_value($values->$name),
+    $self->results_roles_by_values($values);
+}
+
+sub results_roles_by_values {
+  my ( $self, $values ) = @_;
+  return;
+}
+
 sub get_result_by_values {
   my ( $self, $values ) = @_;
-  return unless $self->has_result_by_values($values);
   my $name = $self->name;
   return $self->get_result_by_value($values->$name);
 }
@@ -42,6 +57,11 @@ sub get_result_by_value {
   return $value;
 }
 
+sub viewfield_roles_view_roles_by_results {
+  my ( $self, $results ) = @_;
+  return;
+}
+
 1;
 
 __END__
@@ -54,7 +74,7 @@ SyForm::Field::Process - Role for processed fields
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 AUTHOR
 
