@@ -2,11 +2,12 @@ package SyForm::Values;
 BEGIN {
   $SyForm::Values::AUTHORITY = 'cpan:GETTY';
 }
-$SyForm::Values::VERSION = '0.003';
+$SyForm::Values::VERSION = '0.004';
 use Moose::Role;
 use namespace::autoclean;
 
 with qw(
+  MooseX::Traits
   SyForm::Fields
 );
 
@@ -19,6 +20,17 @@ has syform => (
   )],
 );
 
+sub get_value {
+  my ( $self, $name ) = @_;
+  $self->$name;
+}
+
+sub has_value {
+  my ( $self, $name ) = @_;
+  my $has_name = 'has_'.$name;
+  $self->$has_name;
+}
+
 1;
 
 __END__
@@ -31,7 +43,7 @@ SyForm::Values
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 AUTHOR
 
